"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .accruing_time_off_hour import AccruingTimeOffHour, AccruingTimeOffHourTypedDict
from .accruing_time_off_hour_object import (
    AccruingTimeOffHourObject,
    AccruingTimeOffHourObjectTypedDict,
)
from .admin import Admin, AdminTypedDict
from .apierror import APIError
from .authentication import Authentication, AuthenticationTypedDict
from .benefit_summary import (
    BenefitSummary,
    BenefitSummaryEmployees,
    BenefitSummaryEmployeesTypedDict,
    BenefitSummaryPayPeriod,
    BenefitSummaryPayPeriodTypedDict,
    BenefitSummaryTypedDict,
    PayrollBenefits,
    PayrollBenefitsTypedDict,
)
from .benefit_type_requirements import (
    BenefitTypeRequirements,
    BenefitTypeRequirementsCatchUpDefaultValue,
    BenefitTypeRequirementsCatchUpDefaultValueTypedDict,
    BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue,
    BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict,
    BenefitTypeRequirementsContribution,
    BenefitTypeRequirementsContributionTypedDict,
    BenefitTypeRequirementsCoverageAmountDefaultValue,
    BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict,
    BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue,
    BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict,
    BenefitTypeRequirementsDeductAsPercentageDefaultValue,
    BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict,
    BenefitTypeRequirementsDefaultValue,
    BenefitTypeRequirementsDefaultValueTypedDict,
    BenefitTypeRequirementsLimitOptionDefaultValue,
    BenefitTypeRequirementsLimitOptionDefaultValueTypedDict,
    BenefitTypeRequirementsTypedDict,
    CatchUp,
    CatchUpTypedDict,
    CompanyContributionAnnualMaximum,
    CompanyContributionAnnualMaximumTypedDict,
    CoverageAmount,
    CoverageAmountTypedDict,
    CoverageSalaryMultiplier,
    CoverageSalaryMultiplierTypedDict,
    DeductAsPercentage,
    DeductAsPercentageTypedDict,
    DefaultValue,
    DefaultValueTypedDict,
    EmployeeDeduction,
    EmployeeDeductionTypedDict,
    LimitOption,
    LimitOptionTypedDict,
)
from .child_support_data import (
    Agencies,
    AgenciesTypedDict,
    ChildSupportData,
    ChildSupportDataTypedDict,
    FipsCodes,
    FipsCodesTypedDict,
    Key,
    RequiredAttributes,
    RequiredAttributesTypedDict,
)
from .company import (
    Company,
    CompanyPaidTimeOff,
    CompanyPaidTimeOffTypedDict,
    CompanyStatus,
    CompanyTypedDict,
    Compensations,
    CompensationsTypedDict,
    EntityType,
    Fixed,
    FixedTypedDict,
    FundingType,
    HomeAddress,
    HomeAddressTypedDict,
    Hourly,
    HourlyTypedDict,
    PayScheduleType,
    PrimaryPayrollAdmin,
    PrimaryPayrollAdminTypedDict,
    PrimarySignatory,
    PrimarySignatoryTypedDict,
    Tier,
)
from .company_address import CompanyAddress, CompanyAddressTypedDict
from .company_benefit import CompanyBenefit, CompanyBenefitTypedDict
from .company_benefit_with_employee_benefits import (
    CompanyBenefitWithEmployeeBenefits,
    CompanyBenefitWithEmployeeBenefitsContribution,
    CompanyBenefitWithEmployeeBenefitsContributionTypedDict,
    CompanyBenefitWithEmployeeBenefitsTypedDict,
    CompanyBenefitWithEmployeeBenefitsValue,
    CompanyBenefitWithEmployeeBenefitsValue2,
    CompanyBenefitWithEmployeeBenefitsValue2TypedDict,
    CompanyBenefitWithEmployeeBenefitsValueTiers,
    CompanyBenefitWithEmployeeBenefitsValueTiersTypedDict,
    CompanyBenefitWithEmployeeBenefitsValueTypedDict,
    EmployeeBenefitsModel,
    EmployeeBenefitsModelTypedDict,
)
from .company_custom_field import CompanyCustomField, CompanyCustomFieldTypedDict
from .company_custom_field_list import (
    CompanyCustomFieldList,
    CompanyCustomFieldListTypedDict,
)
from .compensation import (
    Compensation,
    CompensationTypedDict,
    MinimumWages,
    MinimumWagesTypedDict,
    PaymentUnit,
)
from .contractor import (
    Address,
    AddressTypedDict,
    Contractor,
    ContractorOnboardingStatus,
    ContractorPaymentMethod,
    ContractorType,
    ContractorTypedDict,
    WageType,
)
from .contractor_payment import (
    ContractorPayment,
    ContractorPaymentPaymentMethod,
    ContractorPaymentStatus,
    ContractorPaymentTypedDict,
    ContractorPaymentWageType,
)
from .contractor_payment_for_group import (
    ContractorPaymentForGroup,
    ContractorPaymentForGroupPaymentMethod,
    ContractorPaymentForGroupStatus,
    ContractorPaymentForGroupTypedDict,
    ContractorPaymentForGroupWageType,
)
from .contractor_payment_group import (
    ContractorPaymentGroup,
    ContractorPaymentGroupStatus,
    ContractorPaymentGroupTotals,
    ContractorPaymentGroupTotalsTypedDict,
    ContractorPaymentGroupTypedDict,
)
from .contractor_payment_group_minimal import (
    ContractorPaymentGroupMinimal,
    ContractorPaymentGroupMinimalStatus,
    ContractorPaymentGroupMinimalTypedDict,
    Totals,
    TotalsTypedDict,
)
from .contractor_payment_summary import (
    ContractorPaymentSummary,
    ContractorPaymentSummaryTypedDict,
    ContractorPaymentsModel,
    ContractorPaymentsModelTypedDict,
    Total,
    TotalTypedDict,
)
from .contractor_payment_summary_by_dates import (
    ContractorPaymentSummaryByDates,
    ContractorPaymentSummaryByDatesContractorPayments,
    ContractorPaymentSummaryByDatesContractorPaymentsTypedDict,
    ContractorPaymentSummaryByDatesTotal,
    ContractorPaymentSummaryByDatesTotalTypedDict,
    ContractorPaymentSummaryByDatesTypedDict,
)
from .custom_field_type import CustomFieldType
from .delete_departmentop import (
    DeleteDepartmentRequest,
    DeleteDepartmentRequestTypedDict,
)
from .delete_v1_companies_company_id_earning_types_earning_type_uuidop import (
    DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest,
    DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict,
)
from .delete_v1_company_benefits_company_benefit_idop import (
    Base,
    BaseTypedDict,
    DeleteV1CompanyBenefitsCompanyBenefitIDRequest,
    DeleteV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
    DeleteV1CompanyBenefitsCompanyBenefitIDResponseBody,
    DeleteV1CompanyBenefitsCompanyBenefitIDResponseBodyData,
    Errors,
    ErrorsTypedDict,
)
from .delete_v1_compensations_compensation_idop import (
    DeleteV1CompensationsCompensationIDRequest,
    DeleteV1CompensationsCompensationIDRequestTypedDict,
)
from .delete_v1_employee_benefits_employee_benefit_idop import (
    DeleteV1EmployeeBenefitsEmployeeBenefitIDRequest,
    DeleteV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
)
from .delete_v1_employeeop import (
    DeleteV1EmployeeRequest,
    DeleteV1EmployeeRequestTypedDict,
)
from .delete_v1_employees_employee_id_rehireop import (
    DeleteV1EmployeesEmployeeIDRehireRequest,
    DeleteV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .delete_v1_employees_employee_id_terminationsop import (
    DeleteV1EmployeesEmployeeIDTerminationsRequest,
    DeleteV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .delete_v1_home_addresses_home_address_uuidop import (
    DeleteV1HomeAddressesHomeAddressUUIDRequest,
    DeleteV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .delete_v1_jobs_job_idop import (
    DeleteV1JobsJobIDRequest,
    DeleteV1JobsJobIDRequestTypedDict,
)
from .delete_v1_webhook_subscription_uuidop import (
    DeleteV1WebhookSubscriptionUUIDRequest,
    DeleteV1WebhookSubscriptionUUIDRequestTypedDict,
    DeleteV1WebhookSubscriptionUUIDSecurity,
    DeleteV1WebhookSubscriptionUUIDSecurityTypedDict,
)
from .delete_v1_work_addresses_work_address_uuidop import (
    DeleteV1WorkAddressesWorkAddressUUIDRequest,
    DeleteV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .department import (
    ContractorsModel,
    ContractorsModelTypedDict,
    Department,
    DepartmentTypedDict,
    EmployeesModel,
    EmployeesModelTypedDict,
)
from .earning_type import EarningType, EarningTypeTypedDict
from .earning_type_list import EarningTypeList, EarningTypeListTypedDict
from .employee import (
    CurrentEmploymentStatus,
    Employee,
    EmployeeTypedDict,
    OnboardingDocumentsConfig,
    OnboardingDocumentsConfigTypedDict,
    OnboardingStatus,
    PaymentMethod,
)
from .employee_address import EmployeeAddress, EmployeeAddressTypedDict
from .employee_benefit import (
    Contribution,
    ContributionTypedDict,
    DeductionReducesTaxableIncome,
    EmployeeBenefit,
    EmployeeBenefitTypedDict,
    Tiers,
    TiersTypedDict,
    Two,
    TwoTypedDict,
    Value,
    ValueTypedDict,
)
from .employee_benefit_for_company_benefit import (
    EmployeeBenefitForCompanyBenefit,
    EmployeeBenefitForCompanyBenefitContribution,
    EmployeeBenefitForCompanyBenefitContributionTypedDict,
    EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome,
    EmployeeBenefitForCompanyBenefitTypedDict,
    EmployeeBenefitForCompanyBenefitValue,
    EmployeeBenefitForCompanyBenefitValueTypedDict,
    Value2,
    Value2TypedDict,
    ValueTiers,
    ValueTiersTypedDict,
)
from .employee_custom_field import EmployeeCustomField, EmployeeCustomFieldTypedDict
from .employee_work_address import EmployeeWorkAddress, EmployeeWorkAddressTypedDict
from .employment_history_list import (
    EmploymentHistoryList,
    EmploymentHistoryListEmploymentStatus,
    EmploymentHistoryListTypedDict,
)
from .entity_error_object import (
    EntityErrorObject,
    EntityErrorObjectTypedDict,
    Metadata,
    MetadataTypedDict,
)
from .event import Event, EventTypedDict, ResourceType
from .flsa_status_type import FlsaStatusType
from .garnishment import Garnishment, GarnishmentType, GarnishmentTypedDict
from .garnishment_child_support import (
    GarnishmentChildSupport,
    GarnishmentChildSupportTypedDict,
    PaymentPeriod,
)
from .get_companies_departmentsop import (
    GetCompaniesDepartmentsRequest,
    GetCompaniesDepartmentsRequestTypedDict,
)
from .get_departmentop import GetDepartmentRequest, GetDepartmentRequestTypedDict
from .get_employee_ytd_benefit_amounts_from_different_companyop import (
    GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequest,
    GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict,
)
from .get_eventsop import (
    GetEventsRequest,
    GetEventsRequestTypedDict,
    GetEventsSecurity,
    GetEventsSecurityTypedDict,
)
from .get_v1_benefits_benefit_idop import (
    GetV1BenefitsBenefitIDRequest,
    GetV1BenefitsBenefitIDRequestTypedDict,
)
from .get_v1_benefits_benefits_id_requirementsop import (
    GetV1BenefitsBenefitsIDRequirementsRequest,
    GetV1BenefitsBenefitsIDRequirementsRequestTypedDict,
)
from .get_v1_benefits_company_benefit_id_summaryop import (
    GetV1BenefitsCompanyBenefitIDSummaryRequest,
    GetV1BenefitsCompanyBenefitIDSummaryRequestTypedDict,
)
from .get_v1_benefitsop import GetV1BenefitsRequest, GetV1BenefitsRequestTypedDict
from .get_v1_companies_company_id_adminsop import (
    GetV1CompaniesCompanyIDAdminsRequest,
    GetV1CompaniesCompanyIDAdminsRequestTypedDict,
)
from .get_v1_companies_company_id_company_benefitsop import (
    GetV1CompaniesCompanyIDCompanyBenefitsRequest,
    GetV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_payment_contractor_paymentop import (
    GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest,
    GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_payment_groupsop import (
    GetV1CompaniesCompanyIDContractorPaymentGroupsRequest,
    GetV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict,
)
from .get_v1_companies_company_id_contractor_paymentsop import (
    GetV1CompaniesCompanyIDContractorPaymentsRequest,
    GetV1CompaniesCompanyIDContractorPaymentsRequestTypedDict,
    GetV1CompaniesCompanyIDContractorPaymentsResponseBody,
    GetV1CompaniesCompanyIDContractorPaymentsResponseBodyTypedDict,
)
from .get_v1_companies_company_id_custom_fieldsop import (
    GetV1CompaniesCompanyIDCustomFieldsRequest,
    GetV1CompaniesCompanyIDCustomFieldsRequestTypedDict,
)
from .get_v1_companies_company_id_earning_typesop import (
    GetV1CompaniesCompanyIDEarningTypesRequest,
    GetV1CompaniesCompanyIDEarningTypesRequestTypedDict,
)
from .get_v1_companies_company_id_employeesop import (
    GetV1CompaniesCompanyIDEmployeesRequest,
    GetV1CompaniesCompanyIDEmployeesRequestTypedDict,
    Include,
)
from .get_v1_companies_company_id_locationsop import (
    GetV1CompaniesCompanyIDLocationsRequest,
    GetV1CompaniesCompanyIDLocationsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_periodsop import (
    GetV1CompaniesCompanyIDPayPeriodsRequest,
    GetV1CompaniesCompanyIDPayPeriodsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedules_assignmentsop import (
    GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest,
    GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedules_pay_schedule_idop import (
    GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest,
    GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict,
)
from .get_v1_companies_company_id_pay_schedulesop import (
    GetV1CompaniesCompanyIDPaySchedulesRequest,
    GetV1CompaniesCompanyIDPaySchedulesRequestTypedDict,
)
from .get_v1_companies_company_id_payrolls_payroll_idop import (
    GetV1CompaniesCompanyIDPayrollsPayrollIDQueryParamInclude,
    GetV1CompaniesCompanyIDPayrollsPayrollIDRequest,
    GetV1CompaniesCompanyIDPayrollsPayrollIDRequestTypedDict,
)
from .get_v1_companies_company_id_payrollsop import (
    GetV1CompaniesCompanyIDPayrollsQueryParamInclude,
    GetV1CompaniesCompanyIDPayrollsRequest,
    GetV1CompaniesCompanyIDPayrollsRequestTypedDict,
    PayrollTypes,
    ProcessingStatuses,
)
from .get_v1_companies_company_id_unprocessed_termination_pay_periodsop import (
    GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest,
    GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequestTypedDict,
)
from .get_v1_companies_company_uuid_contractorsop import (
    GetV1CompaniesCompanyUUIDContractorsRequest,
    GetV1CompaniesCompanyUUIDContractorsRequestTypedDict,
)
from .get_v1_companiesop import GetV1CompaniesRequest, GetV1CompaniesRequestTypedDict
from .get_v1_company_benefits_company_benefit_id_employee_benefitsop import (
    GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest,
    GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict,
)
from .get_v1_company_benefits_company_benefit_idop import (
    GetV1CompanyBenefitsCompanyBenefitIDRequest,
    GetV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
)
from .get_v1_compensations_compensation_idop import (
    GetV1CompensationsCompensationIDRequest,
    GetV1CompensationsCompensationIDRequestTypedDict,
)
from .get_v1_contractor_payment_groups_contractor_payment_group_idop import (
    GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequest,
    GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict,
)
from .get_v1_contractors_contractor_uuidop import (
    GetV1ContractorsContractorUUIDRequest,
    GetV1ContractorsContractorUUIDRequestTypedDict,
)
from .get_v1_employee_benefits_employee_benefit_idop import (
    GetV1EmployeeBenefitsEmployeeBenefitIDRequest,
    GetV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
)
from .get_v1_employees_employee_id_custom_fieldsop import (
    GetV1EmployeesEmployeeIDCustomFieldsRequest,
    GetV1EmployeesEmployeeIDCustomFieldsRequestTypedDict,
    GetV1EmployeesEmployeeIDCustomFieldsResponseBody,
    GetV1EmployeesEmployeeIDCustomFieldsResponseBodyTypedDict,
)
from .get_v1_employees_employee_id_employee_benefitsop import (
    GetV1EmployeesEmployeeIDEmployeeBenefitsRequest,
    GetV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict,
)
from .get_v1_employees_employee_id_employment_historyop import (
    GetV1EmployeesEmployeeIDEmploymentHistoryRequest,
    GetV1EmployeesEmployeeIDEmploymentHistoryRequestTypedDict,
)
from .get_v1_employees_employee_id_garnishmentsop import (
    GetV1EmployeesEmployeeIDGarnishmentsRequest,
    GetV1EmployeesEmployeeIDGarnishmentsRequestTypedDict,
)
from .get_v1_employees_employee_id_home_addressesop import (
    GetV1EmployeesEmployeeIDHomeAddressesRequest,
    GetV1EmployeesEmployeeIDHomeAddressesRequestTypedDict,
)
from .get_v1_employees_employee_id_jobsop import (
    GetV1EmployeesEmployeeIDJobsQueryParamInclude,
    GetV1EmployeesEmployeeIDJobsRequest,
    GetV1EmployeesEmployeeIDJobsRequestTypedDict,
)
from .get_v1_employees_employee_id_rehireop import (
    GetV1EmployeesEmployeeIDRehireRequest,
    GetV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .get_v1_employees_employee_id_terminationsop import (
    GetV1EmployeesEmployeeIDTerminationsRequest,
    GetV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .get_v1_employees_employee_id_work_addressesop import (
    GetV1EmployeesEmployeeIDWorkAddressesRequest,
    GetV1EmployeesEmployeeIDWorkAddressesRequestTypedDict,
)
from .get_v1_employeesop import (
    GetV1EmployeesRequest,
    GetV1EmployeesRequestTypedDict,
    QueryParamInclude,
)
from .get_v1_garnishments_child_supportop import (
    GetV1GarnishmentsChildSupportRequest,
    GetV1GarnishmentsChildSupportRequestTypedDict,
)
from .get_v1_garnishments_garnishment_idop import (
    GetV1GarnishmentsGarnishmentIDRequest,
    GetV1GarnishmentsGarnishmentIDRequestTypedDict,
)
from .get_v1_home_addresses_home_address_uuidop import (
    GetV1HomeAddressesHomeAddressUUIDRequest,
    GetV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .get_v1_jobs_job_id_compensationsop import (
    GetV1JobsJobIDCompensationsQueryParamInclude,
    GetV1JobsJobIDCompensationsRequest,
    GetV1JobsJobIDCompensationsRequestTypedDict,
)
from .get_v1_jobs_job_idop import (
    GetV1JobsJobIDQueryParamInclude,
    GetV1JobsJobIDRequest,
    GetV1JobsJobIDRequestTypedDict,
)
from .get_v1_locations_location_idop import (
    GetV1LocationsLocationIDRequest,
    GetV1LocationsLocationIDRequestTypedDict,
)
from .get_v1_locations_location_uuid_minimum_wagesop import (
    GetV1LocationsLocationUUIDMinimumWagesRequest,
    GetV1LocationsLocationUUIDMinimumWagesRequestTypedDict,
)
from .get_v1_token_infoop import (
    GetV1TokenInfoRequest,
    GetV1TokenInfoRequestTypedDict,
    GetV1TokenInfoResponseBody,
    GetV1TokenInfoResponseBodyTypedDict,
    GetV1TokenInfoType,
    Resource,
    ResourceOwner,
    ResourceOwnerTypedDict,
    ResourceTypedDict,
)
from .get_v1_webhook_subscription_uuidop import (
    GetV1WebhookSubscriptionUUIDRequest,
    GetV1WebhookSubscriptionUUIDRequestTypedDict,
    GetV1WebhookSubscriptionUUIDSecurity,
    GetV1WebhookSubscriptionUUIDSecurityTypedDict,
)
from .get_v1_webhook_subscription_verification_token_uuidop import (
    GetV1WebhookSubscriptionVerificationTokenUUIDRequest,
    GetV1WebhookSubscriptionVerificationTokenUUIDRequestTypedDict,
    GetV1WebhookSubscriptionVerificationTokenUUIDSecurity,
    GetV1WebhookSubscriptionVerificationTokenUUIDSecurityTypedDict,
)
from .get_v1_webhook_subscriptionsop import (
    GetV1WebhookSubscriptionsRequest,
    GetV1WebhookSubscriptionsRequestTypedDict,
    GetV1WebhookSubscriptionsSecurity,
    GetV1WebhookSubscriptionsSecurityTypedDict,
)
from .get_v1_work_addresses_work_address_uuidop import (
    GetV1WorkAddressesWorkAddressUUIDRequest,
    GetV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .get_version_employees_time_off_activitiesop import (
    GetVersionEmployeesTimeOffActivitiesRequest,
    GetVersionEmployeesTimeOffActivitiesRequestTypedDict,
)
from .job import Job, JobTypedDict
from .location import Location, LocationTypedDict
from .metadata_with_multiple_entities import (
    MetadataWithMultipleEntities,
    MetadataWithMultipleEntitiesTypedDict,
)
from .metadata_with_one_entity import (
    MetadataWithOneEntity,
    MetadataWithOneEntityTypedDict,
)
from .minimum_wage import MinimumWage, MinimumWageTypedDict
from .off_cycle_reason_type import OffCycleReasonType
from .paid_time_off import Name, PaidTimeOff, PaidTimeOffTypedDict
from .pay_period import (
    PayPeriod,
    PayPeriodPayroll,
    PayPeriodPayrollTypedDict,
    PayPeriodTypedDict,
    PayrollType,
)
from .pay_schedule_assignment import (
    PayScheduleAssignment,
    PayScheduleAssignmentTypedDict,
    Type,
)
from .pay_schedule_assignment_department import (
    PayScheduleAssignmentDepartment,
    PayScheduleAssignmentDepartmentTypedDict,
)
from .pay_schedule_assignment_employee import (
    PayScheduleAssignmentEmployee,
    PayScheduleAssignmentEmployeeTypedDict,
)
from .pay_schedule_frequency import PayScheduleFrequency
from .pay_schedule_list import PayScheduleList, PayScheduleListTypedDict
from .pay_schedule_object import PayScheduleObject, PayScheduleObjectTypedDict
from .payroll import Payroll, PayrollTypedDict
from .payroll_company_taxes_type import (
    PayrollCompanyTaxesType,
    PayrollCompanyTaxesTypeTypedDict,
)
from .payroll_credit_blockers_type import (
    PayrollCreditBlockersType,
    PayrollCreditBlockersTypeMetadata,
    PayrollCreditBlockersTypeMetadataTypedDict,
    PayrollCreditBlockersTypeStatus,
    PayrollCreditBlockersTypeTypedDict,
    PayrollCreditBlockersTypeUnblockOptions,
    PayrollCreditBlockersTypeUnblockOptionsTypedDict,
)
from .payroll_employee_compensations_type import (
    Benefits,
    BenefitsTypedDict,
    Deductions,
    DeductionsTypedDict,
    FixedCompensations,
    FixedCompensationsTypedDict,
    HourlyCompensations,
    HourlyCompensationsTypedDict,
    PayrollEmployeeCompensationsType,
    PayrollEmployeeCompensationsTypePaidTimeOff,
    PayrollEmployeeCompensationsTypePaidTimeOffTypedDict,
    PayrollEmployeeCompensationsTypePaymentMethod,
    PayrollEmployeeCompensationsTypeTypedDict,
    Taxes,
    TaxesTypedDict,
)
from .payroll_fixed_compensation_types_type import (
    PayrollFixedCompensationTypesType,
    PayrollFixedCompensationTypesTypeTypedDict,
)
from .payroll_minimal import PayrollMinimal, PayrollMinimalTypedDict
from .payroll_pay_period_type import PayrollPayPeriodType, PayrollPayPeriodTypeTypedDict
from .payroll_payment_speed_changed_type import (
    PayrollPaymentSpeedChangedType,
    PayrollPaymentSpeedChangedTypeTypedDict,
)
from .payroll_payroll_status_meta_type import (
    PayrollPayrollStatusMetaType,
    PayrollPayrollStatusMetaTypeTypedDict,
)
from .payroll_prepared import PayrollPrepared, PayrollPreparedTypedDict
from .payroll_processing_request import (
    PayrollProcessingRequest,
    PayrollProcessingRequestStatus,
    PayrollProcessingRequestTypedDict,
)
from .payroll_submission_blockers_type import (
    PayrollSubmissionBlockersType,
    PayrollSubmissionBlockersTypeMetadata,
    PayrollSubmissionBlockersTypeMetadataTypedDict,
    PayrollSubmissionBlockersTypeStatus,
    PayrollSubmissionBlockersTypeTypedDict,
    UnblockOptions,
    UnblockOptionsTypedDict,
)
from .payroll_totals_type import PayrollTotalsType, PayrollTotalsTypeTypedDict
from .payroll_withholding_pay_period_type import PayrollWithholdingPayPeriodType
from .post_departmentsop import (
    PostDepartmentsRequest,
    PostDepartmentsRequestBody,
    PostDepartmentsRequestBodyTypedDict,
    PostDepartmentsRequestTypedDict,
)
from .post_employee_ytd_benefit_amounts_from_different_company import (
    PostEmployeeYtdBenefitAmountsFromDifferentCompany,
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyTypedDict,
)
from .post_employee_ytd_benefit_amounts_from_different_companyop import (
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequest,
    PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict,
)
from .post_v1_companies_company_id_company_benefitsop import (
    PostV1CompaniesCompanyIDCompanyBenefitsRequest,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestBody,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict,
)
from .post_v1_companies_company_id_contractor_payment_groups_previewop import (
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPayments,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPaymentsTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewPaymentMethod,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequest,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBody,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBodyTypedDict,
    PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestTypedDict,
)
from .post_v1_companies_company_id_earning_typesop import (
    PostV1CompaniesCompanyIDEarningTypesRequest,
    PostV1CompaniesCompanyIDEarningTypesRequestBody,
    PostV1CompaniesCompanyIDEarningTypesRequestBodyTypedDict,
    PostV1CompaniesCompanyIDEarningTypesRequestTypedDict,
)
from .post_v1_companies_company_id_locationsop import (
    PostV1CompaniesCompanyIDLocationsRequest,
    PostV1CompaniesCompanyIDLocationsRequestBody,
    PostV1CompaniesCompanyIDLocationsRequestBodyTypedDict,
    PostV1CompaniesCompanyIDLocationsRequestTypedDict,
)
from .post_v1_companies_company_uuid_contractorsop import (
    PostV1CompaniesCompanyUUIDContractorsRequest,
    PostV1CompaniesCompanyUUIDContractorsRequestBody,
    PostV1CompaniesCompanyUUIDContractorsRequestBodyTypedDict,
    PostV1CompaniesCompanyUUIDContractorsRequestTypedDict,
    PostV1CompaniesCompanyUUIDContractorsType,
    PostV1CompaniesCompanyUUIDContractorsWageType,
)
from .post_v1_compensations_compensation_idop import (
    PostV1CompensationsCompensationIDMinimumWages,
    PostV1CompensationsCompensationIDMinimumWagesTypedDict,
    PostV1CompensationsCompensationIDPaymentUnit,
    PostV1CompensationsCompensationIDRequest,
    PostV1CompensationsCompensationIDRequestBody,
    PostV1CompensationsCompensationIDRequestBodyTypedDict,
    PostV1CompensationsCompensationIDRequestTypedDict,
)
from .post_v1_disconnect_app_integrationop import (
    PostV1DisconnectAppIntegrationRequest,
    PostV1DisconnectAppIntegrationRequestTypedDict,
    PostV1DisconnectAppIntegrationSecurity,
    PostV1DisconnectAppIntegrationSecurityTypedDict,
)
from .post_v1_employees_employee_id_employee_benefitsop import (
    PostV1EmployeesEmployeeIDEmployeeBenefitsContribution,
    PostV1EmployeesEmployeeIDEmployeeBenefitsContributionTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsDeductionReducesTaxableIncome,
    PostV1EmployeesEmployeeIDEmployeeBenefitsLimitOption,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequest,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBody,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsType,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue2,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValue2TypedDict,
    PostV1EmployeesEmployeeIDEmployeeBenefitsValueTypedDict,
)
from .post_v1_employees_employee_id_garnishmentsop import (
    PostV1EmployeesEmployeeIDGarnishmentsGarnishmentType,
    PostV1EmployeesEmployeeIDGarnishmentsRequest,
    PostV1EmployeesEmployeeIDGarnishmentsRequestBody,
    PostV1EmployeesEmployeeIDGarnishmentsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDGarnishmentsRequestTypedDict,
)
from .post_v1_employees_employee_id_home_addressesop import (
    PostV1EmployeesEmployeeIDHomeAddressesRequest,
    PostV1EmployeesEmployeeIDHomeAddressesRequestBody,
    PostV1EmployeesEmployeeIDHomeAddressesRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDHomeAddressesRequestTypedDict,
)
from .post_v1_employees_employee_id_rehireop import (
    PostV1EmployeesEmployeeIDRehireRequest,
    PostV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .post_v1_employees_employee_id_terminationsop import (
    PostV1EmployeesEmployeeIDTerminationsRequest,
    PostV1EmployeesEmployeeIDTerminationsRequestBody,
    PostV1EmployeesEmployeeIDTerminationsRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDTerminationsRequestTypedDict,
)
from .post_v1_employees_employee_id_work_addressesop import (
    PostV1EmployeesEmployeeIDWorkAddressesRequest,
    PostV1EmployeesEmployeeIDWorkAddressesRequestBody,
    PostV1EmployeesEmployeeIDWorkAddressesRequestBodyTypedDict,
    PostV1EmployeesEmployeeIDWorkAddressesRequestTypedDict,
)
from .post_v1_employeesop import (
    PostV1EmployeesRequest,
    PostV1EmployeesRequestBody,
    PostV1EmployeesRequestBodyTypedDict,
    PostV1EmployeesRequestTypedDict,
)
from .post_v1_jobs_job_idop import (
    PostV1JobsJobIDRequest,
    PostV1JobsJobIDRequestBody,
    PostV1JobsJobIDRequestBodyTypedDict,
    PostV1JobsJobIDRequestTypedDict,
)
from .post_v1_payrolls_payroll_id_calculate_accruing_time_off_hoursop import (
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict,
    PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestTypedDict,
)
from .post_v1_provisionop import (
    Addresses,
    AddressesTypedDict,
    PostV1ProvisionCompany,
    PostV1ProvisionCompanyTypedDict,
    PostV1ProvisionRequest,
    PostV1ProvisionRequestBody,
    PostV1ProvisionRequestBodyTypedDict,
    PostV1ProvisionRequestTypedDict,
    PostV1ProvisionResponseBody,
    PostV1ProvisionResponseBodyTypedDict,
    PostV1ProvisionSecurity,
    PostV1ProvisionSecurityTypedDict,
    User,
    UserTypedDict,
)
from .post_v1_webhook_subscriptionop import (
    PostV1WebhookSubscriptionRequest,
    PostV1WebhookSubscriptionRequestBody,
    PostV1WebhookSubscriptionRequestBodyTypedDict,
    PostV1WebhookSubscriptionRequestTypedDict,
    PostV1WebhookSubscriptionSecurity,
    PostV1WebhookSubscriptionSecurityTypedDict,
    PostV1WebhookSubscriptionSubscriptionTypes,
)
from .put_add_people_to_departmentop import (
    PutAddPeopleToDepartmentContractors,
    PutAddPeopleToDepartmentContractorsTypedDict,
    PutAddPeopleToDepartmentEmployees,
    PutAddPeopleToDepartmentEmployeesTypedDict,
    PutAddPeopleToDepartmentRequest,
    PutAddPeopleToDepartmentRequestBody,
    PutAddPeopleToDepartmentRequestBodyTypedDict,
    PutAddPeopleToDepartmentRequestTypedDict,
)
from .put_departmentsop import (
    PutDepartmentsRequest,
    PutDepartmentsRequestBody,
    PutDepartmentsRequestBodyTypedDict,
    PutDepartmentsRequestTypedDict,
)
from .put_remove_people_from_departmentop import (
    PutRemovePeopleFromDepartmentContractors,
    PutRemovePeopleFromDepartmentContractorsTypedDict,
    PutRemovePeopleFromDepartmentEmployees,
    PutRemovePeopleFromDepartmentEmployeesTypedDict,
    PutRemovePeopleFromDepartmentRequest,
    PutRemovePeopleFromDepartmentRequestBody,
    PutRemovePeopleFromDepartmentRequestBodyTypedDict,
    PutRemovePeopleFromDepartmentRequestTypedDict,
)
from .put_v1_companies_company_id_earning_types_earning_type_uuidop import (
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBody,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBodyTypedDict,
    PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict,
)
from .put_v1_companies_company_id_payrolls_payroll_id_prepareop import (
    PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequest,
    PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequestTypedDict,
)
from .put_v1_companies_company_id_payrollsop import (
    EmployeeCompensations,
    EmployeeCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsFixedCompensations,
    PutV1CompaniesCompanyIDPayrollsFixedCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsHourlyCompensations,
    PutV1CompaniesCompanyIDPayrollsHourlyCompensationsTypedDict,
    PutV1CompaniesCompanyIDPayrollsPaidTimeOff,
    PutV1CompaniesCompanyIDPayrollsPaidTimeOffTypedDict,
    PutV1CompaniesCompanyIDPayrollsPaymentMethod,
    PutV1CompaniesCompanyIDPayrollsRequest,
    PutV1CompaniesCompanyIDPayrollsRequestBody,
    PutV1CompaniesCompanyIDPayrollsRequestBodyTypedDict,
    PutV1CompaniesCompanyIDPayrollsRequestTypedDict,
    WithholdingPayPeriod,
)
from .put_v1_companiesop import (
    PutV1CompaniesRequest,
    PutV1CompaniesRequestBody,
    PutV1CompaniesRequestBodyTypedDict,
    PutV1CompaniesRequestTypedDict,
)
from .put_v1_company_benefits_company_benefit_id_employee_benefitsop import (
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict,
    PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict,
)
from .put_v1_company_benefits_company_benefit_idop import (
    PutV1CompanyBenefitsCompanyBenefitIDRequest,
    PutV1CompanyBenefitsCompanyBenefitIDRequestBody,
    PutV1CompanyBenefitsCompanyBenefitIDRequestBodyTypedDict,
    PutV1CompanyBenefitsCompanyBenefitIDRequestTypedDict,
)
from .put_v1_compensations_compensation_idop import (
    PutV1CompensationsCompensationIDMinimumWages,
    PutV1CompensationsCompensationIDMinimumWagesTypedDict,
    PutV1CompensationsCompensationIDPaymentUnit,
    PutV1CompensationsCompensationIDRequest,
    PutV1CompensationsCompensationIDRequestBody,
    PutV1CompensationsCompensationIDRequestBodyTypedDict,
    PutV1CompensationsCompensationIDRequestTypedDict,
)
from .put_v1_contractors_contractor_uuidop import (
    PutV1ContractorsContractorUUIDRequest,
    PutV1ContractorsContractorUUIDRequestBody,
    PutV1ContractorsContractorUUIDRequestBodyTypedDict,
    PutV1ContractorsContractorUUIDRequestTypedDict,
    PutV1ContractorsContractorUUIDType,
    PutV1ContractorsContractorUUIDWageType,
)
from .put_v1_employee_benefits_employee_benefit_idop import (
    PutV1EmployeeBenefitsEmployeeBenefitIDContribution,
    PutV1EmployeeBenefitsEmployeeBenefitIDContributionTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDDeductionReducesTaxableIncome,
    PutV1EmployeeBenefitsEmployeeBenefitIDLimitOption,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequest,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestBody,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestBodyTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDType,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue2,
    PutV1EmployeeBenefitsEmployeeBenefitIDValue2TypedDict,
    PutV1EmployeeBenefitsEmployeeBenefitIDValueTypedDict,
)
from .put_v1_employees_employee_id_rehireop import (
    PutV1EmployeesEmployeeIDRehireEmploymentStatus,
    PutV1EmployeesEmployeeIDRehireRequest,
    PutV1EmployeesEmployeeIDRehireRequestBody,
    PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict,
    PutV1EmployeesEmployeeIDRehireRequestTypedDict,
)
from .put_v1_employeesop import (
    PutV1EmployeesRequest,
    PutV1EmployeesRequestBody,
    PutV1EmployeesRequestBodyTypedDict,
    PutV1EmployeesRequestTypedDict,
)
from .put_v1_garnishments_garnishment_idop import (
    PutV1GarnishmentsGarnishmentIDRequest,
    PutV1GarnishmentsGarnishmentIDRequestBody,
    PutV1GarnishmentsGarnishmentIDRequestBodyTypedDict,
    PutV1GarnishmentsGarnishmentIDRequestTypedDict,
)
from .put_v1_home_addresses_home_address_uuidop import (
    PutV1HomeAddressesHomeAddressUUIDRequest,
    PutV1HomeAddressesHomeAddressUUIDRequestBody,
    PutV1HomeAddressesHomeAddressUUIDRequestBodyTypedDict,
    PutV1HomeAddressesHomeAddressUUIDRequestTypedDict,
)
from .put_v1_jobs_job_idop import (
    PutV1JobsJobIDRequest,
    PutV1JobsJobIDRequestBody,
    PutV1JobsJobIDRequestBodyTypedDict,
    PutV1JobsJobIDRequestTypedDict,
)
from .put_v1_locations_location_idop import (
    PutV1LocationsLocationIDRequest,
    PutV1LocationsLocationIDRequestBody,
    PutV1LocationsLocationIDRequestBodyTypedDict,
    PutV1LocationsLocationIDRequestTypedDict,
)
from .put_v1_terminations_employee_idop import (
    PutV1TerminationsEmployeeIDRequest,
    PutV1TerminationsEmployeeIDRequestBody,
    PutV1TerminationsEmployeeIDRequestBodyTypedDict,
    PutV1TerminationsEmployeeIDRequestTypedDict,
)
from .put_v1_verify_webhook_subscription_uuidop import (
    PutV1VerifyWebhookSubscriptionUUIDRequest,
    PutV1VerifyWebhookSubscriptionUUIDRequestBody,
    PutV1VerifyWebhookSubscriptionUUIDRequestBodyTypedDict,
    PutV1VerifyWebhookSubscriptionUUIDRequestTypedDict,
    PutV1VerifyWebhookSubscriptionUUIDSecurity,
    PutV1VerifyWebhookSubscriptionUUIDSecurityTypedDict,
)
from .put_v1_webhook_subscription_uuidop import (
    PutV1WebhookSubscriptionUUIDRequest,
    PutV1WebhookSubscriptionUUIDRequestBody,
    PutV1WebhookSubscriptionUUIDRequestBodyTypedDict,
    PutV1WebhookSubscriptionUUIDRequestTypedDict,
    PutV1WebhookSubscriptionUUIDSecurity,
    PutV1WebhookSubscriptionUUIDSecurityTypedDict,
    PutV1WebhookSubscriptionUUIDSubscriptionTypes,
)
from .put_v1_work_addresses_work_address_uuidop import (
    PutV1WorkAddressesWorkAddressUUIDRequest,
    PutV1WorkAddressesWorkAddressUUIDRequestBody,
    PutV1WorkAddressesWorkAddressUUIDRequestBodyTypedDict,
    PutV1WorkAddressesWorkAddressUUIDRequestTypedDict,
)
from .refresh_access_tokenop import (
    RefreshAccessTokenRequest,
    RefreshAccessTokenRequestBody,
    RefreshAccessTokenRequestBodyTypedDict,
    RefreshAccessTokenRequestTypedDict,
)
from .rehire import Rehire, RehireEmploymentStatus, RehireTypedDict
from .rehire_body import EmploymentStatus, RehireBody, RehireBodyTypedDict
from .revoke_access_tokenop import (
    RevokeAccessTokenRequest,
    RevokeAccessTokenRequestBody,
    RevokeAccessTokenRequestBodyTypedDict,
    RevokeAccessTokenRequestTypedDict,
)
from .security import Security, SecurityTypedDict
from .sort_order import SortOrder
from .supported_benefit import SupportedBenefit, SupportedBenefitTypedDict
from .termination import Termination, TerminationTypedDict
from .time_off_activity import TimeOffActivity, TimeOffActivityTypedDict, TimeOffType
from .unprocessable_entity_error_object import (
    UnprocessableEntityErrorObject,
    UnprocessableEntityErrorObjectData,
)
from .unprocessed_termination_pay_period import (
    UnprocessedTerminationPayPeriod,
    UnprocessedTerminationPayPeriodTypedDict,
)
from .versionheader import VersionHeader
from .webhook_subscription import (
    Status,
    SubscriptionTypes,
    WebhookSubscription,
    WebhookSubscriptionTypedDict,
)
from .ytd_benefit_amounts_from_different_company import (
    YtdBenefitAmountsFromDifferentCompany,
    YtdBenefitAmountsFromDifferentCompanyTypedDict,
)


__all__ = [
    "APIError",
    "AccruingTimeOffHour",
    "AccruingTimeOffHourObject",
    "AccruingTimeOffHourObjectTypedDict",
    "AccruingTimeOffHourTypedDict",
    "Address",
    "AddressTypedDict",
    "Addresses",
    "AddressesTypedDict",
    "Admin",
    "AdminTypedDict",
    "Agencies",
    "AgenciesTypedDict",
    "Authentication",
    "AuthenticationTypedDict",
    "Base",
    "BaseTypedDict",
    "BenefitSummary",
    "BenefitSummaryEmployees",
    "BenefitSummaryEmployeesTypedDict",
    "BenefitSummaryPayPeriod",
    "BenefitSummaryPayPeriodTypedDict",
    "BenefitSummaryTypedDict",
    "BenefitTypeRequirements",
    "BenefitTypeRequirementsCatchUpDefaultValue",
    "BenefitTypeRequirementsCatchUpDefaultValueTypedDict",
    "BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValue",
    "BenefitTypeRequirementsCompanyContributionAnnualMaximumDefaultValueTypedDict",
    "BenefitTypeRequirementsContribution",
    "BenefitTypeRequirementsContributionTypedDict",
    "BenefitTypeRequirementsCoverageAmountDefaultValue",
    "BenefitTypeRequirementsCoverageAmountDefaultValueTypedDict",
    "BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValue",
    "BenefitTypeRequirementsCoverageSalaryMultiplierDefaultValueTypedDict",
    "BenefitTypeRequirementsDeductAsPercentageDefaultValue",
    "BenefitTypeRequirementsDeductAsPercentageDefaultValueTypedDict",
    "BenefitTypeRequirementsDefaultValue",
    "BenefitTypeRequirementsDefaultValueTypedDict",
    "BenefitTypeRequirementsLimitOptionDefaultValue",
    "BenefitTypeRequirementsLimitOptionDefaultValueTypedDict",
    "BenefitTypeRequirementsTypedDict",
    "Benefits",
    "BenefitsTypedDict",
    "CatchUp",
    "CatchUpTypedDict",
    "ChildSupportData",
    "ChildSupportDataTypedDict",
    "Company",
    "CompanyAddress",
    "CompanyAddressTypedDict",
    "CompanyBenefit",
    "CompanyBenefitTypedDict",
    "CompanyBenefitWithEmployeeBenefits",
    "CompanyBenefitWithEmployeeBenefitsContribution",
    "CompanyBenefitWithEmployeeBenefitsContributionTypedDict",
    "CompanyBenefitWithEmployeeBenefitsTypedDict",
    "CompanyBenefitWithEmployeeBenefitsValue",
    "CompanyBenefitWithEmployeeBenefitsValue2",
    "CompanyBenefitWithEmployeeBenefitsValue2TypedDict",
    "CompanyBenefitWithEmployeeBenefitsValueTiers",
    "CompanyBenefitWithEmployeeBenefitsValueTiersTypedDict",
    "CompanyBenefitWithEmployeeBenefitsValueTypedDict",
    "CompanyContributionAnnualMaximum",
    "CompanyContributionAnnualMaximumTypedDict",
    "CompanyCustomField",
    "CompanyCustomFieldList",
    "CompanyCustomFieldListTypedDict",
    "CompanyCustomFieldTypedDict",
    "CompanyPaidTimeOff",
    "CompanyPaidTimeOffTypedDict",
    "CompanyStatus",
    "CompanyTypedDict",
    "Compensation",
    "CompensationTypedDict",
    "Compensations",
    "CompensationsTypedDict",
    "Contractor",
    "ContractorOnboardingStatus",
    "ContractorPayment",
    "ContractorPaymentForGroup",
    "ContractorPaymentForGroupPaymentMethod",
    "ContractorPaymentForGroupStatus",
    "ContractorPaymentForGroupTypedDict",
    "ContractorPaymentForGroupWageType",
    "ContractorPaymentGroup",
    "ContractorPaymentGroupMinimal",
    "ContractorPaymentGroupMinimalStatus",
    "ContractorPaymentGroupMinimalTypedDict",
    "ContractorPaymentGroupStatus",
    "ContractorPaymentGroupTotals",
    "ContractorPaymentGroupTotalsTypedDict",
    "ContractorPaymentGroupTypedDict",
    "ContractorPaymentMethod",
    "ContractorPaymentPaymentMethod",
    "ContractorPaymentStatus",
    "ContractorPaymentSummary",
    "ContractorPaymentSummaryByDates",
    "ContractorPaymentSummaryByDatesContractorPayments",
    "ContractorPaymentSummaryByDatesContractorPaymentsTypedDict",
    "ContractorPaymentSummaryByDatesTotal",
    "ContractorPaymentSummaryByDatesTotalTypedDict",
    "ContractorPaymentSummaryByDatesTypedDict",
    "ContractorPaymentSummaryTypedDict",
    "ContractorPaymentTypedDict",
    "ContractorPaymentWageType",
    "ContractorPaymentsModel",
    "ContractorPaymentsModelTypedDict",
    "ContractorType",
    "ContractorTypedDict",
    "ContractorsModel",
    "ContractorsModelTypedDict",
    "Contribution",
    "ContributionTypedDict",
    "CoverageAmount",
    "CoverageAmountTypedDict",
    "CoverageSalaryMultiplier",
    "CoverageSalaryMultiplierTypedDict",
    "CurrentEmploymentStatus",
    "CustomFieldType",
    "DeductAsPercentage",
    "DeductAsPercentageTypedDict",
    "DeductionReducesTaxableIncome",
    "Deductions",
    "DeductionsTypedDict",
    "DefaultValue",
    "DefaultValueTypedDict",
    "DeleteDepartmentRequest",
    "DeleteDepartmentRequestTypedDict",
    "DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest",
    "DeleteV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict",
    "DeleteV1CompanyBenefitsCompanyBenefitIDRequest",
    "DeleteV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "DeleteV1CompanyBenefitsCompanyBenefitIDResponseBody",
    "DeleteV1CompanyBenefitsCompanyBenefitIDResponseBodyData",
    "DeleteV1CompensationsCompensationIDRequest",
    "DeleteV1CompensationsCompensationIDRequestTypedDict",
    "DeleteV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "DeleteV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "DeleteV1EmployeeRequest",
    "DeleteV1EmployeeRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDRehireRequest",
    "DeleteV1EmployeesEmployeeIDRehireRequestTypedDict",
    "DeleteV1EmployeesEmployeeIDTerminationsRequest",
    "DeleteV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "DeleteV1HomeAddressesHomeAddressUUIDRequest",
    "DeleteV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "DeleteV1JobsJobIDRequest",
    "DeleteV1JobsJobIDRequestTypedDict",
    "DeleteV1WebhookSubscriptionUUIDRequest",
    "DeleteV1WebhookSubscriptionUUIDRequestTypedDict",
    "DeleteV1WebhookSubscriptionUUIDSecurity",
    "DeleteV1WebhookSubscriptionUUIDSecurityTypedDict",
    "DeleteV1WorkAddressesWorkAddressUUIDRequest",
    "DeleteV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "Department",
    "DepartmentTypedDict",
    "EarningType",
    "EarningTypeList",
    "EarningTypeListTypedDict",
    "EarningTypeTypedDict",
    "Employee",
    "EmployeeAddress",
    "EmployeeAddressTypedDict",
    "EmployeeBenefit",
    "EmployeeBenefitForCompanyBenefit",
    "EmployeeBenefitForCompanyBenefitContribution",
    "EmployeeBenefitForCompanyBenefitContributionTypedDict",
    "EmployeeBenefitForCompanyBenefitDeductionReducesTaxableIncome",
    "EmployeeBenefitForCompanyBenefitTypedDict",
    "EmployeeBenefitForCompanyBenefitValue",
    "EmployeeBenefitForCompanyBenefitValueTypedDict",
    "EmployeeBenefitTypedDict",
    "EmployeeBenefitsModel",
    "EmployeeBenefitsModelTypedDict",
    "EmployeeCompensations",
    "EmployeeCompensationsTypedDict",
    "EmployeeCustomField",
    "EmployeeCustomFieldTypedDict",
    "EmployeeDeduction",
    "EmployeeDeductionTypedDict",
    "EmployeeTypedDict",
    "EmployeeWorkAddress",
    "EmployeeWorkAddressTypedDict",
    "EmployeesModel",
    "EmployeesModelTypedDict",
    "EmploymentHistoryList",
    "EmploymentHistoryListEmploymentStatus",
    "EmploymentHistoryListTypedDict",
    "EmploymentStatus",
    "EntityErrorObject",
    "EntityErrorObjectTypedDict",
    "EntityType",
    "Errors",
    "ErrorsTypedDict",
    "Event",
    "EventTypedDict",
    "FipsCodes",
    "FipsCodesTypedDict",
    "Fixed",
    "FixedCompensations",
    "FixedCompensationsTypedDict",
    "FixedTypedDict",
    "FlsaStatusType",
    "FundingType",
    "Garnishment",
    "GarnishmentChildSupport",
    "GarnishmentChildSupportTypedDict",
    "GarnishmentType",
    "GarnishmentTypedDict",
    "GetCompaniesDepartmentsRequest",
    "GetCompaniesDepartmentsRequestTypedDict",
    "GetDepartmentRequest",
    "GetDepartmentRequestTypedDict",
    "GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequest",
    "GetEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict",
    "GetEventsRequest",
    "GetEventsRequestTypedDict",
    "GetEventsSecurity",
    "GetEventsSecurityTypedDict",
    "GetV1BenefitsBenefitIDRequest",
    "GetV1BenefitsBenefitIDRequestTypedDict",
    "GetV1BenefitsBenefitsIDRequirementsRequest",
    "GetV1BenefitsBenefitsIDRequirementsRequestTypedDict",
    "GetV1BenefitsCompanyBenefitIDSummaryRequest",
    "GetV1BenefitsCompanyBenefitIDSummaryRequestTypedDict",
    "GetV1BenefitsRequest",
    "GetV1BenefitsRequestTypedDict",
    "GetV1CompaniesCompanyIDAdminsRequest",
    "GetV1CompaniesCompanyIDAdminsRequestTypedDict",
    "GetV1CompaniesCompanyIDCompanyBenefitsRequest",
    "GetV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequest",
    "GetV1CompaniesCompanyIDContractorPaymentContractorPaymentRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentGroupsRequest",
    "GetV1CompaniesCompanyIDContractorPaymentGroupsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentsRequest",
    "GetV1CompaniesCompanyIDContractorPaymentsRequestTypedDict",
    "GetV1CompaniesCompanyIDContractorPaymentsResponseBody",
    "GetV1CompaniesCompanyIDContractorPaymentsResponseBodyTypedDict",
    "GetV1CompaniesCompanyIDCustomFieldsRequest",
    "GetV1CompaniesCompanyIDCustomFieldsRequestTypedDict",
    "GetV1CompaniesCompanyIDEarningTypesRequest",
    "GetV1CompaniesCompanyIDEarningTypesRequestTypedDict",
    "GetV1CompaniesCompanyIDEmployeesRequest",
    "GetV1CompaniesCompanyIDEmployeesRequestTypedDict",
    "GetV1CompaniesCompanyIDLocationsRequest",
    "GetV1CompaniesCompanyIDLocationsRequestTypedDict",
    "GetV1CompaniesCompanyIDPayPeriodsRequest",
    "GetV1CompaniesCompanyIDPayPeriodsRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequest",
    "GetV1CompaniesCompanyIDPaySchedulesAssignmentsRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequest",
    "GetV1CompaniesCompanyIDPaySchedulesPayScheduleIDRequestTypedDict",
    "GetV1CompaniesCompanyIDPaySchedulesRequest",
    "GetV1CompaniesCompanyIDPaySchedulesRequestTypedDict",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDQueryParamInclude",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDRequest",
    "GetV1CompaniesCompanyIDPayrollsPayrollIDRequestTypedDict",
    "GetV1CompaniesCompanyIDPayrollsQueryParamInclude",
    "GetV1CompaniesCompanyIDPayrollsRequest",
    "GetV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequest",
    "GetV1CompaniesCompanyIDUnprocessedTerminationPayPeriodsRequestTypedDict",
    "GetV1CompaniesCompanyUUIDContractorsRequest",
    "GetV1CompaniesCompanyUUIDContractorsRequestTypedDict",
    "GetV1CompaniesRequest",
    "GetV1CompaniesRequestTypedDict",
    "GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest",
    "GetV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict",
    "GetV1CompanyBenefitsCompanyBenefitIDRequest",
    "GetV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "GetV1CompensationsCompensationIDRequest",
    "GetV1CompensationsCompensationIDRequestTypedDict",
    "GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequest",
    "GetV1ContractorPaymentGroupsContractorPaymentGroupIDRequestTypedDict",
    "GetV1ContractorsContractorUUIDRequest",
    "GetV1ContractorsContractorUUIDRequestTypedDict",
    "GetV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "GetV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "GetV1EmployeesEmployeeIDCustomFieldsRequest",
    "GetV1EmployeesEmployeeIDCustomFieldsRequestTypedDict",
    "GetV1EmployeesEmployeeIDCustomFieldsResponseBody",
    "GetV1EmployeesEmployeeIDCustomFieldsResponseBodyTypedDict",
    "GetV1EmployeesEmployeeIDEmployeeBenefitsRequest",
    "GetV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict",
    "GetV1EmployeesEmployeeIDEmploymentHistoryRequest",
    "GetV1EmployeesEmployeeIDEmploymentHistoryRequestTypedDict",
    "GetV1EmployeesEmployeeIDGarnishmentsRequest",
    "GetV1EmployeesEmployeeIDGarnishmentsRequestTypedDict",
    "GetV1EmployeesEmployeeIDHomeAddressesRequest",
    "GetV1EmployeesEmployeeIDHomeAddressesRequestTypedDict",
    "GetV1EmployeesEmployeeIDJobsQueryParamInclude",
    "GetV1EmployeesEmployeeIDJobsRequest",
    "GetV1EmployeesEmployeeIDJobsRequestTypedDict",
    "GetV1EmployeesEmployeeIDRehireRequest",
    "GetV1EmployeesEmployeeIDRehireRequestTypedDict",
    "GetV1EmployeesEmployeeIDTerminationsRequest",
    "GetV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "GetV1EmployeesEmployeeIDWorkAddressesRequest",
    "GetV1EmployeesEmployeeIDWorkAddressesRequestTypedDict",
    "GetV1EmployeesRequest",
    "GetV1EmployeesRequestTypedDict",
    "GetV1GarnishmentsChildSupportRequest",
    "GetV1GarnishmentsChildSupportRequestTypedDict",
    "GetV1GarnishmentsGarnishmentIDRequest",
    "GetV1GarnishmentsGarnishmentIDRequestTypedDict",
    "GetV1HomeAddressesHomeAddressUUIDRequest",
    "GetV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "GetV1JobsJobIDCompensationsQueryParamInclude",
    "GetV1JobsJobIDCompensationsRequest",
    "GetV1JobsJobIDCompensationsRequestTypedDict",
    "GetV1JobsJobIDQueryParamInclude",
    "GetV1JobsJobIDRequest",
    "GetV1JobsJobIDRequestTypedDict",
    "GetV1LocationsLocationIDRequest",
    "GetV1LocationsLocationIDRequestTypedDict",
    "GetV1LocationsLocationUUIDMinimumWagesRequest",
    "GetV1LocationsLocationUUIDMinimumWagesRequestTypedDict",
    "GetV1TokenInfoRequest",
    "GetV1TokenInfoRequestTypedDict",
    "GetV1TokenInfoResponseBody",
    "GetV1TokenInfoResponseBodyTypedDict",
    "GetV1TokenInfoType",
    "GetV1WebhookSubscriptionUUIDRequest",
    "GetV1WebhookSubscriptionUUIDRequestTypedDict",
    "GetV1WebhookSubscriptionUUIDSecurity",
    "GetV1WebhookSubscriptionUUIDSecurityTypedDict",
    "GetV1WebhookSubscriptionVerificationTokenUUIDRequest",
    "GetV1WebhookSubscriptionVerificationTokenUUIDRequestTypedDict",
    "GetV1WebhookSubscriptionVerificationTokenUUIDSecurity",
    "GetV1WebhookSubscriptionVerificationTokenUUIDSecurityTypedDict",
    "GetV1WebhookSubscriptionsRequest",
    "GetV1WebhookSubscriptionsRequestTypedDict",
    "GetV1WebhookSubscriptionsSecurity",
    "GetV1WebhookSubscriptionsSecurityTypedDict",
    "GetV1WorkAddressesWorkAddressUUIDRequest",
    "GetV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "GetVersionEmployeesTimeOffActivitiesRequest",
    "GetVersionEmployeesTimeOffActivitiesRequestTypedDict",
    "HomeAddress",
    "HomeAddressTypedDict",
    "Hourly",
    "HourlyCompensations",
    "HourlyCompensationsTypedDict",
    "HourlyTypedDict",
    "Include",
    "Job",
    "JobTypedDict",
    "Key",
    "LimitOption",
    "LimitOptionTypedDict",
    "Location",
    "LocationTypedDict",
    "Metadata",
    "MetadataTypedDict",
    "MetadataWithMultipleEntities",
    "MetadataWithMultipleEntitiesTypedDict",
    "MetadataWithOneEntity",
    "MetadataWithOneEntityTypedDict",
    "MinimumWage",
    "MinimumWageTypedDict",
    "MinimumWages",
    "MinimumWagesTypedDict",
    "Name",
    "OffCycleReasonType",
    "OnboardingDocumentsConfig",
    "OnboardingDocumentsConfigTypedDict",
    "OnboardingStatus",
    "PaidTimeOff",
    "PaidTimeOffTypedDict",
    "PayPeriod",
    "PayPeriodPayroll",
    "PayPeriodPayrollTypedDict",
    "PayPeriodTypedDict",
    "PayScheduleAssignment",
    "PayScheduleAssignmentDepartment",
    "PayScheduleAssignmentDepartmentTypedDict",
    "PayScheduleAssignmentEmployee",
    "PayScheduleAssignmentEmployeeTypedDict",
    "PayScheduleAssignmentTypedDict",
    "PayScheduleFrequency",
    "PayScheduleList",
    "PayScheduleListTypedDict",
    "PayScheduleObject",
    "PayScheduleObjectTypedDict",
    "PayScheduleType",
    "PaymentMethod",
    "PaymentPeriod",
    "PaymentUnit",
    "Payroll",
    "PayrollBenefits",
    "PayrollBenefitsTypedDict",
    "PayrollCompanyTaxesType",
    "PayrollCompanyTaxesTypeTypedDict",
    "PayrollCreditBlockersType",
    "PayrollCreditBlockersTypeMetadata",
    "PayrollCreditBlockersTypeMetadataTypedDict",
    "PayrollCreditBlockersTypeStatus",
    "PayrollCreditBlockersTypeTypedDict",
    "PayrollCreditBlockersTypeUnblockOptions",
    "PayrollCreditBlockersTypeUnblockOptionsTypedDict",
    "PayrollEmployeeCompensationsType",
    "PayrollEmployeeCompensationsTypePaidTimeOff",
    "PayrollEmployeeCompensationsTypePaidTimeOffTypedDict",
    "PayrollEmployeeCompensationsTypePaymentMethod",
    "PayrollEmployeeCompensationsTypeTypedDict",
    "PayrollFixedCompensationTypesType",
    "PayrollFixedCompensationTypesTypeTypedDict",
    "PayrollMinimal",
    "PayrollMinimalTypedDict",
    "PayrollPayPeriodType",
    "PayrollPayPeriodTypeTypedDict",
    "PayrollPaymentSpeedChangedType",
    "PayrollPaymentSpeedChangedTypeTypedDict",
    "PayrollPayrollStatusMetaType",
    "PayrollPayrollStatusMetaTypeTypedDict",
    "PayrollPrepared",
    "PayrollPreparedTypedDict",
    "PayrollProcessingRequest",
    "PayrollProcessingRequestStatus",
    "PayrollProcessingRequestTypedDict",
    "PayrollSubmissionBlockersType",
    "PayrollSubmissionBlockersTypeMetadata",
    "PayrollSubmissionBlockersTypeMetadataTypedDict",
    "PayrollSubmissionBlockersTypeStatus",
    "PayrollSubmissionBlockersTypeTypedDict",
    "PayrollTotalsType",
    "PayrollTotalsTypeTypedDict",
    "PayrollType",
    "PayrollTypedDict",
    "PayrollTypes",
    "PayrollWithholdingPayPeriodType",
    "PostDepartmentsRequest",
    "PostDepartmentsRequestBody",
    "PostDepartmentsRequestBodyTypedDict",
    "PostDepartmentsRequestTypedDict",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompany",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequest",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyRequestTypedDict",
    "PostEmployeeYtdBenefitAmountsFromDifferentCompanyTypedDict",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequest",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestBody",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPayments",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewContractorPaymentsTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewPaymentMethod",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequest",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBody",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDContractorPaymentGroupsPreviewRequestTypedDict",
    "PostV1CompaniesCompanyIDEarningTypesRequest",
    "PostV1CompaniesCompanyIDEarningTypesRequestBody",
    "PostV1CompaniesCompanyIDEarningTypesRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDEarningTypesRequestTypedDict",
    "PostV1CompaniesCompanyIDLocationsRequest",
    "PostV1CompaniesCompanyIDLocationsRequestBody",
    "PostV1CompaniesCompanyIDLocationsRequestBodyTypedDict",
    "PostV1CompaniesCompanyIDLocationsRequestTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsRequest",
    "PostV1CompaniesCompanyUUIDContractorsRequestBody",
    "PostV1CompaniesCompanyUUIDContractorsRequestBodyTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsRequestTypedDict",
    "PostV1CompaniesCompanyUUIDContractorsType",
    "PostV1CompaniesCompanyUUIDContractorsWageType",
    "PostV1CompensationsCompensationIDMinimumWages",
    "PostV1CompensationsCompensationIDMinimumWagesTypedDict",
    "PostV1CompensationsCompensationIDPaymentUnit",
    "PostV1CompensationsCompensationIDRequest",
    "PostV1CompensationsCompensationIDRequestBody",
    "PostV1CompensationsCompensationIDRequestBodyTypedDict",
    "PostV1CompensationsCompensationIDRequestTypedDict",
    "PostV1DisconnectAppIntegrationRequest",
    "PostV1DisconnectAppIntegrationRequestTypedDict",
    "PostV1DisconnectAppIntegrationSecurity",
    "PostV1DisconnectAppIntegrationSecurityTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsContribution",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsContributionTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsDeductionReducesTaxableIncome",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsLimitOption",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequest",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBody",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsRequestTypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsType",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue2",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValue2TypedDict",
    "PostV1EmployeesEmployeeIDEmployeeBenefitsValueTypedDict",
    "PostV1EmployeesEmployeeIDGarnishmentsGarnishmentType",
    "PostV1EmployeesEmployeeIDGarnishmentsRequest",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestBody",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDGarnishmentsRequestTypedDict",
    "PostV1EmployeesEmployeeIDHomeAddressesRequest",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestBody",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDHomeAddressesRequestTypedDict",
    "PostV1EmployeesEmployeeIDRehireRequest",
    "PostV1EmployeesEmployeeIDRehireRequestTypedDict",
    "PostV1EmployeesEmployeeIDTerminationsRequest",
    "PostV1EmployeesEmployeeIDTerminationsRequestBody",
    "PostV1EmployeesEmployeeIDTerminationsRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDTerminationsRequestTypedDict",
    "PostV1EmployeesEmployeeIDWorkAddressesRequest",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestBody",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestBodyTypedDict",
    "PostV1EmployeesEmployeeIDWorkAddressesRequestTypedDict",
    "PostV1EmployeesRequest",
    "PostV1EmployeesRequestBody",
    "PostV1EmployeesRequestBodyTypedDict",
    "PostV1EmployeesRequestTypedDict",
    "PostV1JobsJobIDRequest",
    "PostV1JobsJobIDRequestBody",
    "PostV1JobsJobIDRequestBodyTypedDict",
    "PostV1JobsJobIDRequestTypedDict",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequest",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBody",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestBodyTypedDict",
    "PostV1PayrollsPayrollIDCalculateAccruingTimeOffHoursRequestTypedDict",
    "PostV1ProvisionCompany",
    "PostV1ProvisionCompanyTypedDict",
    "PostV1ProvisionRequest",
    "PostV1ProvisionRequestBody",
    "PostV1ProvisionRequestBodyTypedDict",
    "PostV1ProvisionRequestTypedDict",
    "PostV1ProvisionResponseBody",
    "PostV1ProvisionResponseBodyTypedDict",
    "PostV1ProvisionSecurity",
    "PostV1ProvisionSecurityTypedDict",
    "PostV1WebhookSubscriptionRequest",
    "PostV1WebhookSubscriptionRequestBody",
    "PostV1WebhookSubscriptionRequestBodyTypedDict",
    "PostV1WebhookSubscriptionRequestTypedDict",
    "PostV1WebhookSubscriptionSecurity",
    "PostV1WebhookSubscriptionSecurityTypedDict",
    "PostV1WebhookSubscriptionSubscriptionTypes",
    "PrimaryPayrollAdmin",
    "PrimaryPayrollAdminTypedDict",
    "PrimarySignatory",
    "PrimarySignatoryTypedDict",
    "ProcessingStatuses",
    "PutAddPeopleToDepartmentContractors",
    "PutAddPeopleToDepartmentContractorsTypedDict",
    "PutAddPeopleToDepartmentEmployees",
    "PutAddPeopleToDepartmentEmployeesTypedDict",
    "PutAddPeopleToDepartmentRequest",
    "PutAddPeopleToDepartmentRequestBody",
    "PutAddPeopleToDepartmentRequestBodyTypedDict",
    "PutAddPeopleToDepartmentRequestTypedDict",
    "PutDepartmentsRequest",
    "PutDepartmentsRequestBody",
    "PutDepartmentsRequestBodyTypedDict",
    "PutDepartmentsRequestTypedDict",
    "PutRemovePeopleFromDepartmentContractors",
    "PutRemovePeopleFromDepartmentContractorsTypedDict",
    "PutRemovePeopleFromDepartmentEmployees",
    "PutRemovePeopleFromDepartmentEmployeesTypedDict",
    "PutRemovePeopleFromDepartmentRequest",
    "PutRemovePeopleFromDepartmentRequestBody",
    "PutRemovePeopleFromDepartmentRequestBodyTypedDict",
    "PutRemovePeopleFromDepartmentRequestTypedDict",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequest",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBody",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDEarningTypesEarningTypeUUIDRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsFixedCompensations",
    "PutV1CompaniesCompanyIDPayrollsFixedCompensationsTypedDict",
    "PutV1CompaniesCompanyIDPayrollsHourlyCompensations",
    "PutV1CompaniesCompanyIDPayrollsHourlyCompensationsTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPaidTimeOff",
    "PutV1CompaniesCompanyIDPayrollsPaidTimeOffTypedDict",
    "PutV1CompaniesCompanyIDPayrollsPaymentMethod",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequest",
    "PutV1CompaniesCompanyIDPayrollsPayrollIDPrepareRequestTypedDict",
    "PutV1CompaniesCompanyIDPayrollsRequest",
    "PutV1CompaniesCompanyIDPayrollsRequestBody",
    "PutV1CompaniesCompanyIDPayrollsRequestBodyTypedDict",
    "PutV1CompaniesCompanyIDPayrollsRequestTypedDict",
    "PutV1CompaniesRequest",
    "PutV1CompaniesRequestBody",
    "PutV1CompaniesRequestBodyTypedDict",
    "PutV1CompaniesRequestTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequest",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBody",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestBodyTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDEmployeeBenefitsRequestTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDRequest",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestBody",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestBodyTypedDict",
    "PutV1CompanyBenefitsCompanyBenefitIDRequestTypedDict",
    "PutV1CompensationsCompensationIDMinimumWages",
    "PutV1CompensationsCompensationIDMinimumWagesTypedDict",
    "PutV1CompensationsCompensationIDPaymentUnit",
    "PutV1CompensationsCompensationIDRequest",
    "PutV1CompensationsCompensationIDRequestBody",
    "PutV1CompensationsCompensationIDRequestBodyTypedDict",
    "PutV1CompensationsCompensationIDRequestTypedDict",
    "PutV1ContractorsContractorUUIDRequest",
    "PutV1ContractorsContractorUUIDRequestBody",
    "PutV1ContractorsContractorUUIDRequestBodyTypedDict",
    "PutV1ContractorsContractorUUIDRequestTypedDict",
    "PutV1ContractorsContractorUUIDType",
    "PutV1ContractorsContractorUUIDWageType",
    "PutV1EmployeeBenefitsEmployeeBenefitIDContribution",
    "PutV1EmployeeBenefitsEmployeeBenefitIDContributionTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDDeductionReducesTaxableIncome",
    "PutV1EmployeeBenefitsEmployeeBenefitIDLimitOption",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequest",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestBody",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestBodyTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDRequestTypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDType",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue2",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValue2TypedDict",
    "PutV1EmployeeBenefitsEmployeeBenefitIDValueTypedDict",
    "PutV1EmployeesEmployeeIDRehireEmploymentStatus",
    "PutV1EmployeesEmployeeIDRehireRequest",
    "PutV1EmployeesEmployeeIDRehireRequestBody",
    "PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict",
    "PutV1EmployeesEmployeeIDRehireRequestTypedDict",
    "PutV1EmployeesRequest",
    "PutV1EmployeesRequestBody",
    "PutV1EmployeesRequestBodyTypedDict",
    "PutV1EmployeesRequestTypedDict",
    "PutV1GarnishmentsGarnishmentIDRequest",
    "PutV1GarnishmentsGarnishmentIDRequestBody",
    "PutV1GarnishmentsGarnishmentIDRequestBodyTypedDict",
    "PutV1GarnishmentsGarnishmentIDRequestTypedDict",
    "PutV1HomeAddressesHomeAddressUUIDRequest",
    "PutV1HomeAddressesHomeAddressUUIDRequestBody",
    "PutV1HomeAddressesHomeAddressUUIDRequestBodyTypedDict",
    "PutV1HomeAddressesHomeAddressUUIDRequestTypedDict",
    "PutV1JobsJobIDRequest",
    "PutV1JobsJobIDRequestBody",
    "PutV1JobsJobIDRequestBodyTypedDict",
    "PutV1JobsJobIDRequestTypedDict",
    "PutV1LocationsLocationIDRequest",
    "PutV1LocationsLocationIDRequestBody",
    "PutV1LocationsLocationIDRequestBodyTypedDict",
    "PutV1LocationsLocationIDRequestTypedDict",
    "PutV1TerminationsEmployeeIDRequest",
    "PutV1TerminationsEmployeeIDRequestBody",
    "PutV1TerminationsEmployeeIDRequestBodyTypedDict",
    "PutV1TerminationsEmployeeIDRequestTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDRequest",
    "PutV1VerifyWebhookSubscriptionUUIDRequestBody",
    "PutV1VerifyWebhookSubscriptionUUIDRequestBodyTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDRequestTypedDict",
    "PutV1VerifyWebhookSubscriptionUUIDSecurity",
    "PutV1VerifyWebhookSubscriptionUUIDSecurityTypedDict",
    "PutV1WebhookSubscriptionUUIDRequest",
    "PutV1WebhookSubscriptionUUIDRequestBody",
    "PutV1WebhookSubscriptionUUIDRequestBodyTypedDict",
    "PutV1WebhookSubscriptionUUIDRequestTypedDict",
    "PutV1WebhookSubscriptionUUIDSecurity",
    "PutV1WebhookSubscriptionUUIDSecurityTypedDict",
    "PutV1WebhookSubscriptionUUIDSubscriptionTypes",
    "PutV1WorkAddressesWorkAddressUUIDRequest",
    "PutV1WorkAddressesWorkAddressUUIDRequestBody",
    "PutV1WorkAddressesWorkAddressUUIDRequestBodyTypedDict",
    "PutV1WorkAddressesWorkAddressUUIDRequestTypedDict",
    "QueryParamInclude",
    "RefreshAccessTokenRequest",
    "RefreshAccessTokenRequestBody",
    "RefreshAccessTokenRequestBodyTypedDict",
    "RefreshAccessTokenRequestTypedDict",
    "Rehire",
    "RehireBody",
    "RehireBodyTypedDict",
    "RehireEmploymentStatus",
    "RehireTypedDict",
    "RequiredAttributes",
    "RequiredAttributesTypedDict",
    "Resource",
    "ResourceOwner",
    "ResourceOwnerTypedDict",
    "ResourceType",
    "ResourceTypedDict",
    "RevokeAccessTokenRequest",
    "RevokeAccessTokenRequestBody",
    "RevokeAccessTokenRequestBodyTypedDict",
    "RevokeAccessTokenRequestTypedDict",
    "Security",
    "SecurityTypedDict",
    "SortOrder",
    "Status",
    "SubscriptionTypes",
    "SupportedBenefit",
    "SupportedBenefitTypedDict",
    "Taxes",
    "TaxesTypedDict",
    "Termination",
    "TerminationTypedDict",
    "Tier",
    "Tiers",
    "TiersTypedDict",
    "TimeOffActivity",
    "TimeOffActivityTypedDict",
    "TimeOffType",
    "Total",
    "TotalTypedDict",
    "Totals",
    "TotalsTypedDict",
    "Two",
    "TwoTypedDict",
    "Type",
    "UnblockOptions",
    "UnblockOptionsTypedDict",
    "UnprocessableEntityErrorObject",
    "UnprocessableEntityErrorObjectData",
    "UnprocessedTerminationPayPeriod",
    "UnprocessedTerminationPayPeriodTypedDict",
    "User",
    "UserTypedDict",
    "Value",
    "Value2",
    "Value2TypedDict",
    "ValueTiers",
    "ValueTiersTypedDict",
    "ValueTypedDict",
    "VersionHeader",
    "WageType",
    "WebhookSubscription",
    "WebhookSubscriptionTypedDict",
    "WithholdingPayPeriod",
    "YtdBenefitAmountsFromDifferentCompany",
    "YtdBenefitAmountsFromDifferentCompanyTypedDict",
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .company_custom_field import CompanyCustomField, CompanyCustomFieldTypedDict
from gusto_app_integration.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CompanyCustomFieldListTypedDict(TypedDict):
    r"""Example response"""

    custom_fields: NotRequired[List[CompanyCustomFieldTypedDict]]


class CompanyCustomFieldList(BaseModel):
    r"""Example response"""

    custom_fields: Optional[List[CompanyCustomField]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from gusto_app_integration.types import BaseModel
from gusto_app_integration.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict(TypedDict):
    description: str
    r"""The description of the company benefit. For example, a company may offer multiple benefits with an ID of 1 (for Medical Insurance). The description would show something more specific like “Kaiser Permanente” or “Blue Cross/ Blue Shield”."""
    benefit_type: NotRequired[int]
    r"""The ID of the benefit to which the company benefit belongs."""
    active: NotRequired[bool]
    r"""Whether this benefit is active for employee participation."""
    responsible_for_employer_taxes: NotRequired[bool]
    r"""Whether the employer is subject to pay employer taxes when an employee is on leave. Only applicable to third party sick pay benefits."""
    responsible_for_employee_w2: NotRequired[bool]
    r"""Whether the employer is subject to file W-2 forms for an employee on leave. Only applicable to third party sick pay benefits."""


class PostV1CompaniesCompanyIDCompanyBenefitsRequestBody(BaseModel):
    description: str
    r"""The description of the company benefit. For example, a company may offer multiple benefits with an ID of 1 (for Medical Insurance). The description would show something more specific like “Kaiser Permanente” or “Blue Cross/ Blue Shield”."""

    benefit_type: Optional[int] = None
    r"""The ID of the benefit to which the company benefit belongs."""

    active: Optional[bool] = True
    r"""Whether this benefit is active for employee participation."""

    responsible_for_employer_taxes: Optional[bool] = None
    r"""Whether the employer is subject to pay employer taxes when an employee is on leave. Only applicable to third party sick pay benefits."""

    responsible_for_employee_w2: Optional[bool] = None
    r"""Whether the employer is subject to file W-2 forms for an employee on leave. Only applicable to third party sick pay benefits."""


class PostV1CompaniesCompanyIDCompanyBenefitsRequestTypedDict(TypedDict):
    company_id: str
    r"""The UUID of the company"""
    request_body: PostV1CompaniesCompanyIDCompanyBenefitsRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PostV1CompaniesCompanyIDCompanyBenefitsRequest(BaseModel):
    company_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the company"""

    request_body: Annotated[
        PostV1CompaniesCompanyIDCompanyBenefitsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .versionheader import VersionHeader
from enum import Enum
from gusto_app_integration.types import BaseModel
from gusto_app_integration.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PutV1EmployeesEmployeeIDRehireEmploymentStatus(str, Enum):
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""

    PART_TIME = "part_time"
    FULL_TIME = "full_time"
    PART_TIME_ELIGIBLE = "part_time_eligible"
    VARIABLE = "variable"
    SEASONAL = "seasonal"
    NOT_SET = "not_set"


class PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict(TypedDict):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    effective_date: str
    r"""The day when the employee returns to work."""
    file_new_hire_report: bool
    r"""The boolean flag indicating whether Gusto will file a new hire report for the employee."""
    work_location_uuid: str
    r"""The uuid of the employee's work location."""
    employment_status: NotRequired[PutV1EmployeesEmployeeIDRehireEmploymentStatus]
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""
    two_percent_shareholder: NotRequired[bool]
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""


class PutV1EmployeesEmployeeIDRehireRequestBody(BaseModel):
    version: str
    r"""The current version of the object. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    effective_date: str
    r"""The day when the employee returns to work."""

    file_new_hire_report: bool
    r"""The boolean flag indicating whether Gusto will file a new hire report for the employee."""

    work_location_uuid: str
    r"""The uuid of the employee's work location."""

    employment_status: Optional[PutV1EmployeesEmployeeIDRehireEmploymentStatus] = None
    r"""The employee's employment status. Supplying an invalid option will set the employment_status to *not_set*."""

    two_percent_shareholder: Optional[bool] = None
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""


class PutV1EmployeesEmployeeIDRehireRequestTypedDict(TypedDict):
    employee_id: str
    r"""The UUID of the employee"""
    request_body: PutV1EmployeesEmployeeIDRehireRequestBodyTypedDict
    x_gusto_api_version: NotRequired[VersionHeader]
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""


class PutV1EmployeesEmployeeIDRehireRequest(BaseModel):
    employee_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The UUID of the employee"""

    request_body: Annotated[
        PutV1EmployeesEmployeeIDRehireRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_gusto_api_version: Annotated[
        Optional[VersionHeader],
        pydantic.Field(alias="X-Gusto-API-Version"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = VersionHeader.TWO_THOUSAND_AND_TWENTY_FOUR_MINUS_04_MINUS_01
    r"""Determines the date-based API version associated with your API call. If none is provided, your application's [minimum API version](https://docs.gusto.com/embedded-payroll/docs/api-versioning#minimum-api-version) is used."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .employee_custom_field import EmployeeCustomField, EmployeeCustomFieldTypedDict
from .garnishment import Garnishment, GarnishmentTypedDict
from .job import Job, JobTypedDict
from .paid_time_off import PaidTimeOff, PaidTimeOffTypedDict
from .termination import Termination, TerminationTypedDict
from enum import Enum
from gusto_app_integration.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class OnboardingStatus(str, Enum):
    r"""The current onboarding status of the employee"""

    ONBOARDING_COMPLETED = "onboarding_completed"
    ADMIN_ONBOARDING_INCOMPLETE = "admin_onboarding_incomplete"
    SELF_ONBOARDING_PENDING_INVITE = "self_onboarding_pending_invite"
    SELF_ONBOARDING_INVITED = "self_onboarding_invited"
    SELF_ONBOARDING_INVITED_STARTED = "self_onboarding_invited_started"
    SELF_ONBOARDING_INVITED_OVERDUE = "self_onboarding_invited_overdue"
    SELF_ONBOARDING_COMPLETED_BY_EMPLOYEE = "self_onboarding_completed_by_employee"
    SELF_ONBOARDING_AWAITING_ADMIN_REVIEW = "self_onboarding_awaiting_admin_review"


class OnboardingDocumentsConfigTypedDict(TypedDict):
    r"""Configuration for an employee onboarding documents during onboarding"""

    uuid: NotRequired[Nullable[str]]
    r"""The UUID of the onboarding documents config"""
    i9_document: NotRequired[bool]
    r"""Whether to include Form I-9 for an employee during onboarding"""


class OnboardingDocumentsConfig(BaseModel):
    r"""Configuration for an employee onboarding documents during onboarding"""

    uuid: OptionalNullable[str] = UNSET
    r"""The UUID of the onboarding documents config"""

    i9_document: Optional[bool] = None
    r"""Whether to include Form I-9 for an employee during onboarding"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["uuid", "i9_document"]
        nullable_fields = ["uuid"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class PaymentMethod(str, Enum):
    r"""The employee's payment method"""

    DIRECT_DEPOSIT = "Direct Deposit"
    CHECK = "Check"


class CurrentEmploymentStatus(str, Enum):
    r"""The current employment status of the employee. Full-time employees work 30+ hours per week. Part-time employees are split into two groups: those that work 20-29 hours a week, and those that work under 20 hours a week. Variable employees have hours that vary each week. Seasonal employees are hired for 6 months of the year or less."""

    FULL_TIME = "full_time"
    PART_TIME_UNDER_TWENTY_HOURS = "part_time_under_twenty_hours"
    PART_TIME_TWENTY_PLUS_HOURS = "part_time_twenty_plus_hours"
    VARIABLE = "variable"
    SEASONAL = "seasonal"


class EmployeeTypedDict(TypedDict):
    r"""The representation of an employee in Gusto."""

    uuid: str
    r"""The UUID of the employee in Gusto."""
    first_name: str
    last_name: str
    middle_initial: NotRequired[Nullable[str]]
    email: NotRequired[Nullable[str]]
    r"""The personal email address of the employee. This is provided to support syncing users between our system and yours. You may not use this email address for any other purpose (e.g. marketing)."""
    company_uuid: NotRequired[str]
    r"""The UUID of the company the employee is employed by."""
    manager_uuid: NotRequired[Nullable[str]]
    r"""The UUID of the employee's manager."""
    version: NotRequired[str]
    r"""The current version of the employee. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""
    department: NotRequired[Nullable[str]]
    r"""The employee's department in the company."""
    terminated: NotRequired[bool]
    r"""Whether the employee is terminated."""
    two_percent_shareholder: NotRequired[Nullable[bool]]
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""
    onboarded: NotRequired[bool]
    r"""Whether the employee has completed onboarding."""
    onboarding_status: NotRequired[OnboardingStatus]
    r"""The current onboarding status of the employee"""
    onboarding_documents_config: NotRequired[OnboardingDocumentsConfigTypedDict]
    r"""Configuration for an employee onboarding documents during onboarding"""
    jobs: NotRequired[List[JobTypedDict]]
    eligible_paid_time_off: NotRequired[List[PaidTimeOffTypedDict]]
    terminations: NotRequired[List[TerminationTypedDict]]
    garnishments: NotRequired[List[GarnishmentTypedDict]]
    custom_fields: NotRequired[List[EmployeeCustomFieldTypedDict]]
    r"""Custom fields are only included for the employee if the include param has the custom_fields value set"""
    date_of_birth: NotRequired[Nullable[str]]
    has_ssn: NotRequired[bool]
    r"""Indicates whether the employee has an SSN in Gusto."""
    ssn: NotRequired[str]
    r"""Deprecated. This field always returns an empty string."""
    phone: NotRequired[Nullable[str]]
    preferred_first_name: NotRequired[Nullable[str]]
    payment_method: NotRequired[PaymentMethod]
    r"""The employee's payment method"""
    work_email: NotRequired[Nullable[str]]
    r"""The work email address of the employee. This is provided to support syncing users between our system and yours. You may not use this email address for any other purpose (e.g. marketing)."""
    current_employment_status: NotRequired[Nullable[CurrentEmploymentStatus]]
    r"""The current employment status of the employee. Full-time employees work 30+ hours per week. Part-time employees are split into two groups: those that work 20-29 hours a week, and those that work under 20 hours a week. Variable employees have hours that vary each week. Seasonal employees are hired for 6 months of the year or less."""


class Employee(BaseModel):
    r"""The representation of an employee in Gusto."""

    uuid: str
    r"""The UUID of the employee in Gusto."""

    first_name: str

    last_name: str

    middle_initial: OptionalNullable[str] = UNSET

    email: OptionalNullable[str] = UNSET
    r"""The personal email address of the employee. This is provided to support syncing users between our system and yours. You may not use this email address for any other purpose (e.g. marketing)."""

    company_uuid: Optional[str] = None
    r"""The UUID of the company the employee is employed by."""

    manager_uuid: OptionalNullable[str] = UNSET
    r"""The UUID of the employee's manager."""

    version: Optional[str] = None
    r"""The current version of the employee. See the [versioning guide](https://docs.gusto.com/embedded-payroll/docs/idempotency) for information on how to use this field."""

    department: OptionalNullable[str] = UNSET
    r"""The employee's department in the company."""

    terminated: Optional[bool] = None
    r"""Whether the employee is terminated."""

    two_percent_shareholder: OptionalNullable[bool] = UNSET
    r"""Whether the employee is a two percent shareholder of the company. This field only applies to companies with an S-Corp entity type."""

    onboarded: Optional[bool] = None
    r"""Whether the employee has completed onboarding."""

    onboarding_status: Optional[OnboardingStatus] = None
    r"""The current onboarding status of the employee"""

    onboarding_documents_config: Optional[OnboardingDocumentsConfig] = None
    r"""Configuration for an employee onboarding documents during onboarding"""

    jobs: Optional[List[Job]] = None

    eligible_paid_time_off: Optional[List[PaidTimeOff]] = None

    terminations: Optional[List[Termination]] = None

    garnishments: Optional[List[Garnishment]] = None

    custom_fields: Optional[List[EmployeeCustomField]] = None
    r"""Custom fields are only included for the employee if the include param has the custom_fields value set"""

    date_of_birth: OptionalNullable[str] = UNSET

    has_ssn: Optional[bool] = None
    r"""Indicates whether the employee has an SSN in Gusto."""

    ssn: Optional[str] = None
    r"""Deprecated. This field always returns an empty string."""

    phone: OptionalNullable[str] = UNSET

    preferred_first_name: OptionalNullable[str] = UNSET

    payment_method: Optional[PaymentMethod] = PaymentMethod.CHECK
    r"""The employee's payment method"""

    work_email: OptionalNullable[str] = UNSET
    r"""The work email address of the employee. This is provided to support syncing users between our system and yours. You may not use this email address for any other purpose (e.g. marketing)."""

    current_employment_status: OptionalNullable[CurrentEmploymentStatus] = UNSET
    r"""The current employment status of the employee. Full-time employees work 30+ hours per week. Part-time employees are split into two groups: those that work 20-29 hours a week, and those that work under 20 hours a week. Variable employees have hours that vary each week. Seasonal employees are hired for 6 months of the year or less."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "middle_initial",
            "email",
            "company_uuid",
            "manager_uuid",
            "version",
            "department",
            "terminated",
            "two_percent_shareholder",
            "onboarded",
            "onboarding_status",
            "onboarding_documents_config",
            "jobs",
            "eligible_paid_time_off",
            "terminations",
            "garnishments",
            "custom_fields",
            "date_of_birth",
            "has_ssn",
            "ssn",
            "phone",
            "preferred_first_name",
            "payment_method",
            "work_email",
            "current_employment_status",
        ]
        nullable_fields = [
            "middle_initial",
            "email",
            "manager_uuid",
            "department",
            "two_percent_shareholder",
            "date_of_birth",
            "phone",
            "preferred_first_name",
            "work_email",
            "current_employment_status",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
